==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/km-KH/admin/users/message.php <==
<?php

return array(

    'accepted'                  => 'អ្នក​បាន​ទទួល​យក​ទ្រព្យ​សកម្ម​នេះ​ដោយ​ជោគជ័យ។',
    'declined'                  => 'អ្នកបានបដិសេធដោយជោគជ័យនូវទ្រព្យសកម្មនេះ។',
    'bulk_manager_warn'	        => 'អ្នកប្រើប្រាស់របស់អ្នកត្រូវបានអាប់ដេតដោយជោគជ័យ ទោះជាយ៉ាងណាក៏ដោយ ធាតុគ្រប់គ្រងរបស់អ្នកមិនត្រូវបានរក្សាទុកទេ ដោយសារអ្នកគ្រប់គ្រងដែលអ្នកបានជ្រើសរើសក៏ស្ថិតនៅក្នុងបញ្ជីអ្នកប្រើប្រាស់ដែលត្រូវកែសម្រួលដែរ ហើយអ្នកប្រើប្រាស់ប្រហែលជាមិនមែនជាអ្នកគ្រប់គ្រងផ្ទាល់របស់ពួកគេទេ។ សូមជ្រើសរើសអ្នកប្រើប្រាស់របស់អ្នកម្តងទៀត ដោយមិនរាប់បញ្ចូលអ្នកគ្រប់គ្រង។',
    'user_exists'               => 'អ្នកប្រើប្រាស់មានហើយ!',
    'user_not_found'            => 'អ្នកប្រើប្រាស់មិនមានទេ។',
    'user_login_required'       => 'The login field is required',
    'user_has_no_assets_assigned' => 'មិន​មាន​ទ្រព្យ​សកម្ម​ដែល​ត្រូវ​បាន​ផ្ដល់​ឱ្យ​អ្នក​ប្រើ​នា​ពេល​បច្ចុប្បន្ន​នេះ​។',
    'user_password_required'    => 'ពាក្យសម្ងាត់គឺត្រូវបានទាមទារ។',
    'insufficient_permissions'  => 'Insufficient Permissions.',
    'user_deleted_warning'      => 'អ្នក​ប្រើ​នេះ​ត្រូវ​បាន​លុប។ អ្នកនឹងត្រូវស្តារអ្នកប្រើប្រាស់នេះឡើងវិញ ដើម្បីកែសម្រួលពួកគេ ឬផ្តល់ទ្រព្យសម្បត្តិថ្មី។',
    'ldap_not_configured'        => 'ការរួមបញ្ចូល LDAP មិនត្រូវបានកំណត់រចនាសម្ព័ន្ធសម្រាប់ការដំឡើងនេះទេ។',
    'password_resets_sent'      => 'អ្នកប្រើប្រាស់ដែលបានជ្រើសរើសដែលត្រូវបានធ្វើឱ្យសកម្ម និងមានអាសយដ្ឋានអ៊ីមែលត្រឹមត្រូវត្រូវបានផ្ញើតំណកំណត់ពាក្យសម្ងាត់ឡើងវិញ។',
    'password_reset_sent'       => 'តំណ​កំណត់​ពាក្យ​សម្ងាត់​ឡើងវិញ​ត្រូវ​បាន​ផ្ញើ​ទៅ៖ អ៊ីមែល!',
    'user_has_no_email'         => 'អ្នកប្រើប្រាស់នេះមិនមានអាសយដ្ឋានអ៊ីមែលនៅក្នុងកម្រងព័ត៌មានរបស់ពួកគេទេ។',
    'log_record_not_found'        => 'រកមិនឃើញកំណត់ហេតុដែលត្រូវគ្នាសម្រាប់អ្នកប្រើប្រាស់នេះទេ។',


    'success' => array(
        'create'    => 'អ្នកប្រើប្រាស់ត្រូវបានបង្កើតដោយជោគជ័យ។',
        'update'    => 'អ្នកប្រើប្រាស់ត្រូវបានធ្វើបច្ចុប្បន្នភាពដោយជោគជ័យ។',
        'update_bulk'    => 'អ្នកប្រើប្រាស់ត្រូវបានធ្វើបច្ចុប្បន្នភាពដោយជោគជ័យ!',
        'delete'    => 'អ្នកប្រើប្រាស់ត្រូវបានលុបដោយជោគជ័យ។',
        'ban'       => 'អ្នកប្រើប្រាស់ត្រូវបានហាមឃាត់ដោយជោគជ័យ។',
        'unban'     => 'អ្នកប្រើប្រាស់ត្រូវបានលុបចោលដោយជោគជ័យ។',
        'suspend'   => 'អ្នកប្រើប្រាស់ត្រូវបានផ្អាកដោយជោគជ័យ។',
        'unsuspend' => 'User was successfully unsuspended.',
        'restored'  => 'អ្នកប្រើប្រាស់ត្រូវបានស្ដារឡើងវិញដោយជោគជ័យ។',
        'import'    => 'អ្នកប្រើប្រាស់បាននាំចូលដោយជោគជ័យ។',
    ),

    'error' => array(
        'create' => 'មាន​បញ្ហា​ក្នុង​ការ​បង្កើត​អ្នក​ប្រើ។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'update' => 'មានបញ្ហាក្នុងការអាប់ដេតអ្នកប្រើប្រាស់។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'delete' => 'មានបញ្ហាក្នុងការលុបអ្នកប្រើប្រាស់។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'delete_has_assets' => 'អ្នក​ប្រើ​នេះ​មាន​ធាតុ​ដែល​បាន​កំណត់ ហើយ​មិន​អាច​លុប​បាន​ទេ។',
        'unsuspend' => 'មានបញ្ហាក្នុងការឈប់ផ្អាកអ្នកប្រើប្រាស់។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'import'    => 'មានបញ្ហាក្នុងការនាំចូលអ្នកប្រើប្រាស់។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'asset_already_accepted' => 'ទ្រព្យសកម្មនេះត្រូវបានទទួលរួចហើយ។',
        'accept_or_decline' => 'អ្នក​ត្រូវតែ​ទទួល​យក ឬ​បដិសេធ​ទ្រព្យសកម្ម​នេះ។',
        'incorrect_user_accepted' => 'The asset you have attempted to accept was not checked out to you.',
        'ldap_could_not_connect' => 'មិនអាចភ្ជាប់ទៅម៉ាស៊ីនមេ LDAP បានទេ។ សូមពិនិត្យមើលការកំណត់រចនាសម្ព័ន្ធម៉ាស៊ីនមេ LDAP របស់អ្នកនៅក្នុងឯកសារកំណត់រចនាសម្ព័ន្ធ LDAP ។ <br>កំហុសពីម៉ាស៊ីនមេ LDAP៖',
        'ldap_could_not_bind' => 'មិនអាចភ្ជាប់ទៅម៉ាស៊ីនមេ LDAP បានទេ។ សូមពិនិត្យមើលការកំណត់រចនាសម្ព័ន្ធម៉ាស៊ីនមេ LDAP របស់អ្នកនៅក្នុងឯកសារកំណត់រចនាសម្ព័ន្ធ LDAP ។ <br>កំហុសពីម៉ាស៊ីនមេ LDAP៖ ',
        'ldap_could_not_search' => 'មិនអាចស្វែងរកម៉ាស៊ីនមេ LDAP បានទេ។ សូមពិនិត្យមើលការកំណត់រចនាសម្ព័ន្ធម៉ាស៊ីនមេ LDAP របស់អ្នកនៅក្នុងឯកសារកំណត់រចនាសម្ព័ន្ធ LDAP ។ <br>កំហុសពីម៉ាស៊ីនមេ LDAP៖',
        'ldap_could_not_get_entries' => 'មិនអាចទទួលបានធាតុពីម៉ាស៊ីនមេ LDAP ទេ។ សូមពិនិត្យមើលការកំណត់រចនាសម្ព័ន្ធម៉ាស៊ីនមេ LDAP របស់អ្នកនៅក្នុងឯកសារកំណត់រចនាសម្ព័ន្ធ LDAP ។ <br>កំហុសពីម៉ាស៊ីនមេ LDAP៖',
        'password_ldap' => 'ពាក្យសម្ងាត់សម្រាប់គណនីនេះត្រូវបានគ្រប់គ្រងដោយ LDAP/Active Directory។ សូមទាក់ទងផ្នែក IT របស់អ្នក ដើម្បីផ្លាស់ប្តូរពាក្យសម្ងាត់របស់អ្នក។ ',
    ),

    'deletefile' => array(
        'error'   => 'ឯកសារមិនត្រូវបានលុបទេ។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'success' => 'ឯកសារត្រូវបានលុបដោយជោគជ័យ។',
    ),

    'upload' => array(
        'error'   => 'ឯកសារ (ច្រើន) មិនត្រូវបានផ្ទុកឡើងទេ។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'success' => 'ឯកសារ (ច្រើន) ដែលបានបង្ហោះដោយជោគជ័យ។',
        'nofiles' => 'អ្នកមិនបានជ្រើសរើសឯកសារណាមួយសម្រាប់ផ្ទុកឡើងទេ។',
        'invalidfiles' => 'ឯកសារមួយ ឬច្រើនរបស់អ្នកមានទំហំធំពេក ឬជាប្រភេទឯកសារដែលមិនត្រូវបានអនុញ្ញាត។ ប្រភេទឯកសារដែលបានអនុញ្ញាតគឺ png, gif, jpg, doc, docx, pdf, និង txt ។',
    ),

    'inventorynotification' => array(
        'error'   => 'អ្នក​ប្រើ​នេះ​មិន​បាន​កំណត់​អ៊ីមែល​ទេ។',
        'success' => 'អ្នកប្រើប្រាស់ត្រូវបានជូនដំណឹងអំពីសារពើភ័ណ្ឌបច្ចុប្បន្នរបស់ពួកគេ។'
    )
);

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/km-KH/admin/users/message.php <==
<?php

return array(

    'accepted'                  => 'អ្នក​បាន​ទទួល​យក​ទ្រព្យ​សកម្ម​នេះ​ដោយ​ជោគជ័យ។',
    'declined'                  => 'អ្នកបានបដិសេធដោយជោគជ័យនូវទ្រព្យសកម្មនេះ។',
    'bulk_manager_warn'	        => 'អ្នកប្រើប្រាស់របស់អ្នកត្រូវបានអាប់ដេតដោយជោគជ័យ ទោះជាយ៉ាងណាក៏ដោយ ធាតុគ្រប់គ្រងរបស់អ្នកមិនត្រូវបានរក្សាទុកទេ ដោយសារអ្នកគ្រប់គ្រងដែលអ្នកបានជ្រើសរើសក៏ស្ថិតនៅក្នុងបញ្ជីអ្នកប្រើប្រាស់ដែលត្រូវកែសម្រួលដែរ ហើយអ្នកប្រើប្រាស់ប្រហែលជាមិនមែនជាអ្នកគ្រប់គ្រងផ្ទាល់របស់ពួកគេទេ។ សូមជ្រើសរើសអ្នកប្រើប្រាស់របស់អ្នកម្តងទៀត ដោយមិនរាប់បញ្ចូលអ្នកគ្រប់គ្រង។',
    'user_exists'               => 'អ្នកប្រើប្រាស់មានហើយ!',
    'user_not_found'            => 'User does not exist or you do not have permission view them.',
    'user_login_required'       => 'The login field is required',
    'user_has_no_assets_assigned' => 'មិន​មាន​ទ្រព្យ​សកម្ម​ដែល​ត្រូវ​បាន​ផ្ដល់​ឱ្យ​អ្នក​ប្រើ​នា​ពេល​បច្ចុប្បន្ន​នេះ​។',
    'user_password_required'    => 'ពាក្យសម្ងាត់គឺត្រូវបានទាមទារ។',
    'insufficient_permissions'  => 'Insufficient Permissions.',
    'user_deleted_warning'      => 'អ្នក​ប្រើ​នេះ​ត្រូវ​បាន​លុប។ អ្នកនឹងត្រូវស្តារអ្នកប្រើប្រាស់នេះឡើងវិញ ដើម្បីកែសម្រួលពួកគេ ឬផ្តល់ទ្រព្យសម្បត្តិថ្មី។',
    'ldap_not_configured'        => 'ការរួមបញ្ចូល LDAP មិនត្រូវបានកំណត់រចនាសម្ព័ន្ធសម្រាប់ការដំឡើងនេះទេ។',
    'password_resets_sent'      => 'អ្នកប្រើប្រាស់ដែលបានជ្រើសរើសដែលត្រូវបានធ្វើឱ្យសកម្ម និងមានអាសយដ្ឋានអ៊ីមែលត្រឹមត្រូវត្រូវបានផ្ញើតំណកំណត់ពាក្យសម្ងាត់ឡើងវិញ។',
    'password_reset_sent'       => 'តំណ​កំណត់​ពាក្យ​សម្ងាត់​ឡើងវិញ​ត្រូវ​បាន​ផ្ញើ​ទៅ៖ អ៊ីមែល!',
    'user_has_no_email'         => 'អ្នកប្រើប្រាស់នេះមិនមានអាសយដ្ឋានអ៊ីមែលនៅក្នុងកម្រងព័ត៌មានរបស់ពួកគេទេ។',
    'log_record_not_found'        => 'រកមិនឃើញកំណត់ហេតុដែលត្រូវគ្នាសម្រាប់អ្នកប្រើប្រាស់នេះទេ។',


    'success' => array(
        'create'    => 'អ្នកប្រើប្រាស់ត្រូវបានបង្កើតដោយជោគជ័យ។',
        'update'    => 'អ្នកប្រើប្រាស់ត្រូវបានធ្វើបច្ចុប្បន្នភាពដោយជោគជ័យ។',
        'update_bulk'    => 'អ្នកប្រើប្រាស់ត្រូវបានធ្វើបច្ចុប្បន្នភាពដោយជោគជ័យ!',
        'delete'    => 'អ្នកប្រើប្រាស់ត្រូវបានលុបដោយជោគជ័យ។',
        'ban'       => 'អ្នកប្រើប្រាស់ត្រូវបានហាមឃាត់ដោយជោគជ័យ។',
        'unban'     => 'អ្នកប្រើប្រាស់ត្រូវបានលុបចោលដោយជោគជ័យ។',
        'suspend'   => 'អ្នកប្រើប្រាស់ត្រូវបានផ្អាកដោយជោគជ័យ។',
        'unsuspend' => 'User was successfully unsuspended.',
        'restored'  => 'អ្នកប្រើប្រាស់ត្រូវបានស្ដារឡើងវិញដោយជោគជ័យ។',
        'import'    => 'អ្នកប្រើប្រាស់បាននាំចូលដោយជោគជ័យ។',
    ),

    'error' => array(
        'create' => 'មាន​បញ្ហា​ក្នុង​ការ​បង្កើត​អ្នក​ប្រើ។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'update' => 'មានបញ្ហាក្នុងការអាប់ដេតអ្នកប្រើប្រាស់។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'delete' => 'មានបញ្ហាក្នុងការលុបអ្នកប្រើប្រាស់។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'delete_has_assets' => 'អ្នក​ប្រើ​នេះ​មាន​ធាតុ​ដែល​បាន​កំណត់ ហើយ​មិន​អាច​លុប​បាន​ទេ។',
        'delete_has_assets_var' => 'This user still has an asset assigned. Please check it in first.|This user still has :count assets assigned. Please check their assets in first.',
        'delete_has_licenses_var' => 'This user still has a license seats assigned. Please check it in first.|This user still has :count license seats assigned. Please check them in first.',
        'delete_has_accessories_var' => 'This user still has an accessory assigned. Please check it in first.|This user still has :count accessories assigned. Please check their assets in first.',
        'delete_has_locations_var' => 'This user still manages a location. Please select another manager first.|This user still manages :count locations. Please select another manager first.',
        'delete_has_users_var' => 'This user still manages another user. Please select another manager for that user first.|This user still manages :count users. Please select another manager for them first.',
        'unsuspend' => 'មានបញ្ហាក្នុងការឈប់ផ្អាកអ្នកប្រើប្រាស់។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'import'    => 'មានបញ្ហាក្នុងការនាំចូលអ្នកប្រើប្រាស់។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'asset_already_accepted' => 'ទ្រព្យសកម្មនេះត្រូវបានទទួលរួចហើយ។',
        'accept_or_decline' => 'អ្នក​ត្រូវតែ​ទទួល​យក ឬ​បដិសេធ​ទ្រព្យសកម្ម​នេះ។',
        'cannot_delete_yourself' => 'We would feel really bad if you deleted yourself, please reconsider.',
        'incorrect_user_accepted' => 'The asset you have attempted to accept was not checked out to you.',
        'ldap_could_not_connect' => 'មិនអាចភ្ជាប់ទៅម៉ាស៊ីនមេ LDAP បានទេ។ សូមពិនិត្យមើលការកំណត់រចនាសម្ព័ន្ធម៉ាស៊ីនមេ LDAP របស់អ្នកនៅក្នុងឯកសារកំណត់រចនាសម្ព័ន្ធ LDAP ។ <br>កំហុសពីម៉ាស៊ីនមេ LDAP៖',
        'ldap_could_not_bind' => 'មិនអាចភ្ជាប់ទៅម៉ាស៊ីនមេ LDAP បានទេ។ សូមពិនិត្យមើលការកំណត់រចនាសម្ព័ន្ធម៉ាស៊ីនមេ LDAP របស់អ្នកនៅក្នុងឯកសារកំណត់រចនាសម្ព័ន្ធ LDAP ។ <br>កំហុសពីម៉ាស៊ីនមេ LDAP៖ ',
        'ldap_could_not_search' => 'មិនអាចស្វែងរកម៉ាស៊ីនមេ LDAP បានទេ។ សូមពិនិត្យមើលការកំណត់រចនាសម្ព័ន្ធម៉ាស៊ីនមេ LDAP របស់អ្នកនៅក្នុងឯកសារកំណត់រចនាសម្ព័ន្ធ LDAP ។ <br>កំហុសពីម៉ាស៊ីនមេ LDAP៖',
        'ldap_could_not_get_entries' => 'មិនអាចទទួលបានធាតុពីម៉ាស៊ីនមេ LDAP ទេ។ សូមពិនិត្យមើលការកំណត់រចនាសម្ព័ន្ធម៉ាស៊ីនមេ LDAP របស់អ្នកនៅក្នុងឯកសារកំណត់រចនាសម្ព័ន្ធ LDAP ។ <br>កំហុសពីម៉ាស៊ីនមេ LDAP៖',
        'password_ldap' => 'ពាក្យសម្ងាត់សម្រាប់គណនីនេះត្រូវបានគ្រប់គ្រងដោយ LDAP/Active Directory។ សូមទាក់ទងផ្នែក IT របស់អ្នក ដើម្បីផ្លាស់ប្តូរពាក្យសម្ងាត់របស់អ្នក។ ',
        'multi_company_items_assigned' => 'This user has items assigned that belong to a different company. Please check them in or edit their company.'
    ),

    'deletefile' => array(
        'error'   => 'ឯកសារមិនត្រូវបានលុបទេ។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'success' => 'ឯកសារត្រូវបានលុបដោយជោគជ័យ។',
    ),

    'upload' => array(
        'error'   => 'ឯកសារ (ច្រើន) មិនត្រូវបានផ្ទុកឡើងទេ។ សូម​ព្យាយាម​ម្តង​ទៀត។',
        'success' => 'ឯកសារ (ច្រើន) ដែលបានបង្ហោះដោយជោគជ័យ។',
        'nofiles' => 'អ្នកមិនបានជ្រើសរើសឯកសារណាមួយសម្រាប់ផ្ទុកឡើងទេ។',
        'invalidfiles' => 'ឯកសារមួយ ឬច្រើនរបស់អ្នកមានទំហំធំពេក ឬជាប្រភេទឯកសារដែលមិនត្រូវបានអនុញ្ញាត។ ប្រភេទឯកសារដែលបានអនុញ្ញាតគឺ png, gif, jpg, doc, docx, pdf, និង txt ។',
    ),

    'inventorynotification' => array(
        'error'   => 'អ្នក​ប្រើ​នេះ​មិន​បាន​កំណត់​អ៊ីមែល​ទេ។',
        'success' => 'អ្នកប្រើប្រាស់ត្រូវបានជូនដំណឹងអំពីសារពើភ័ណ្ឌបច្ចុប្បន្នរបស់ពួកគេ។'
    )
);
